<?php
    function scb_messenger_bot_post() {
        //labels array added inside the function and precedes args array
        $labels = array(
            'name' => _x( 'Messenger Bot', 'post type general name' ),
            'singular_name' => _x( 'Messenger Bot', 'post type singular name' ),
            'add_new' => _x( 'Add New', 'Messenger Bot' ),
            'add_new_item' => __( 'Add New Messenger Bot' ),
            'edit_item' => __( 'Edit Messenger Bot' ),
            'new_item' => __( 'New Messenger Bot' ),
            'all_items' => __( 'All Messenger Bot' ),
            'view_item' => __( 'View Messenger Bot' ),
            'search_items' => __( 'Search Messenger Bot' ),
            'not_found' => __( 'No Messenger Bot found' ),
            'not_found_in_trash' => __( 'No Messenger Bot found in the Trash' ),
            'parent_item_colon' => '',
            'menu_name' => 'Messenger Bots'
        );
        
        // args array
        $args = array(
            'labels' => $labels,
            'description' => __('Displays Messenger Bot and their ratings','messenger-bot'),
            'public' => true,
            'menu_position' => 4,
            'supports' => array( 'title' ),
            'has_archive' => false,
        );
        
        register_post_type( 'messenger_bot', $args );
    }
    add_action( 'init', 'scb_messenger_bot_post' );

    /**
     * Register meta boxes.
     */
    function scb_register_meta_boxes() {
        add_meta_box( 'scb-1', __( 'Config ', 'scb' ), 'scb_display_callback', 'messenger_bot' );
    }
    add_action( 'add_meta_boxes', 'scb_register_meta_boxes' );

    /**
     * Meta box display callback.
     *
     * @param WP_Post $post Current post object.
     */
    function scb_display_callback( $post ) {
        include plugin_dir_path( __FILE__ ) . '../part/form.php';
    }

    /**
     * Save meta box content.
     *
     * @param int $post_id Post ID
     */
    function scb_save_meta_box( $post_id ) {
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
        if ( $parent_id = wp_is_post_revision( $post_id ) ) {
            $post_id = $parent_id;
        }
        $fields = [
            'scb_token',
            'scb_key',
            'scb_error_msg',
        ];
        foreach ( $fields as $field ) {
            if ( array_key_exists( $field, $_POST ) ) {
                update_post_meta( $post_id, $field, sanitize_text_field( $_POST[$field] ) );
            }
        }
    }
    add_action( 'save_post', 'scb_save_meta_box' );

    // Adding the metaboxes
    add_action( 'add_meta_boxes', 'scb_add_messengerbot_meta' );

    /* Saving the data */
    add_action( 'save_post', 'scb_messengerbot_meta_save' );

    /* Adding the main meta box container to the post editor screen */
    function scb_add_messengerbot_meta() {
        add_meta_box(
            'messengerbot-details',
            'Messengerbot Details',
            'scb_messengerbot_details_init',
            'messenger_bot');
    }

    function scb_getOptionType($edit = null, $type = null, $incremental = '%1$s') {
        $array_select = array(
            'output_text_sender' => __('text','messenger-bot'),
            'output_all_sender' => __('Latest post','messenger-bot'),
            'output_category_sender' => __('Latest post of category','messenger-bot'),
            'output_tag_sender' => __('Latest post of tag','messenger-bot')
        );
        $option = '<select name="messengerbotDetails['.$incremental.'][response_type]" id="messengerbotDetails" onchange="changetype(event)">';
        foreach ($array_select as $value => $text) {
            $selected = '';
            if($type == $value && $edit) $selected = 'selected';
            $option .= '<option value="'.$value.'" '.$selected.'>'.$text.'</option>';
        }
        $option .= '</select>';

        return $option;
    }

    function scb_getOptionCategory($edit = null, $type = null, $incremental = '%1$s') {
        $array_select = scb_utilities::scb_getCategory();
        $option = '<select name="messengerbotDetails['.$incremental.'][response_cat]" class="categoryBlock" id="messengerbotCategoryDetails">';
        foreach ($array_select as $value => $text) {
            $selected = '';
            if($type == $value && $edit) $selected = 'selected';
            $option .= '<option value="'.$value.'" '.$selected.'>'.$text.'</option>';
        }
        $option .= '</select>';

        return $option;
    }

    function scb_getOptionTag($edit = null, $type = null, $incremental = '%1$s') {
        $array_select = scb_utilities::scb_getTag();
        $option = '<select name="messengerbotDetails['.$incremental.'][response_tag]" class="tagBlock" id="messengerbotTagDetails">';
        foreach ($array_select as $value => $text) {
            $selected = '';
            if($type == $value && $edit) $selected = 'selected';
            $option .= '<option value="'.$value.'" '.$selected.'>'.$text.'</option>';
        }
        $option .= '</select>';

        return $option;
    }

    /*Printing the box content */
    function scb_messengerbot_details_init() {
        global $post;
        // Use nonce for verification
        wp_nonce_field( plugin_basename( __FILE__ ), 'messengerbot_nonce' );
        include plugin_dir_path( __FILE__ ) . '../part/messengerbot_meta_item.php';

    }

    /* Save function for the entered data */
    function scb_messengerbot_meta_save( $post_id ) {
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
            return;
        // Verifying the nonce
        if ( !isset( $_POST['messengerbot_nonce'] ) )
            return;

        if ( !wp_verify_nonce( $_POST['messengerbot_nonce'], plugin_basename( __FILE__ ) ) )
            return;
        // Updating the messengerbotDetails meta data
        $messengerbotDetails = scb_utilities::sanitizePostInput($_POST['messengerbotDetails']) ;
        
        update_post_meta($post_id,'messengerbotDetails',$messengerbotDetails);
    }


/********************* */

    /**
     * Register meta boxes.
     */
    function scb_register_message_failure_list_boxes() {
        add_meta_box( 'scb-2', __( 'Error list ', 'scb' ), 'scb_display_message_failure_list_callback', 'messenger_bot' );
    }
    add_action( 'add_meta_boxes', 'scb_register_message_failure_list_boxes' );

    /**
     * Meta box display callback.
     *
     * @param WP_Post $post Current post object.
     */
    function scb_display_message_failure_list_callback( $post ) {
        include plugin_dir_path( __FILE__ ) . '../part/form_message_failure_list.php';
    }

    /**
     * Save meta box content.
     *
     * @param int $post_id Post ID
     */
    function scb_save_message_failure_list_box( $post_id ) {
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
        if ( $parent_id = wp_is_post_revision( $post_id ) ) {
            $post_id = $parent_id;
        }
        $fields = [
            'scb_message_failure_list'
        ];
        foreach ( $fields as $field ) {
            if ( array_key_exists( $field, $_POST ) ) {
                update_post_meta( $post_id, $field, sanitize_text_field( $_POST[$field] ) );
            }
        }
    }
    add_action( 'save_post', 'scb_save_message_failure_list_box' );

    // Adding the metaboxes
    add_action( 'add_meta_boxes', 'scb_add_messengerbot_message_failure_list' );

?>